@@ -3,7 +3,6 @@ package Test::Code::TidyAll::Plugin;
 use Capture::Tiny qw(capture);
 use Code::TidyAll::Util qw(pushd tempdir_simple);
 use Code::TidyAll;
-use File::Path qw(mkpath);
 use File::Slurp::Tiny qw(read_file);
 use Test::Class::Most parent => 'Code::TidyAll::Test::Class';
 use Test::Differences qw( eq_or_diff );
@@ -15,23 +14,8 @@ my $Test = Test::Builder->new;
 
 sub startup : Tests(startup => no_plan) {
     my $self = shift;
+
     $self->{root_dir} = tempdir_simple();
-
-    my $bin = 'node_modules/.bin';
-    mkpath( $bin, 0, 0755 );
-    my $pushed = pushd($bin);
-
-    my %links = (
-        'css-beautify'  => '../js-beautify/js/bin/css-beautify.js',
-        'cssunminifier' => '../cssunminifier/bin/cssunminifier',
-        'html-beautify' => '../js-beautify/js/bin/html-beautify.js',
-        'js-beautify'   => '../js-beautify/js/bin/js-beautify.js',
-        'jshint'        => '../jshint/bin/jshint',
-        'jslint'        => '../jslint/bin/jslint.js',
-    );
-    for my $from ( keys %links ) {
-        symlink $links{$from}, $from unless -l $from;
-    }
 }
 
 sub plugin_class {
@@ -40,7 +24,7 @@ sub plugin_class {
     return ( split( '::', ref($self) ) )[-1];
 }
 
-sub test_filename { 'foo.txt' }
+sub test_filename {'foo.txt'}
 
 sub tidyall {
     my ( $self, %p ) = @_;
@@ -50,8 +34,8 @@ sub tidyall {
     $ENV{PATH} .= q{:} . $extra if $extra;
 
     my $plugin_class = $self->plugin_class;
-    my %plugin_conf = ( $plugin_class => { select => '*', %{ $p{conf} || {} } } );
-    my $ct = Code::TidyAll->new(
+    my %plugin_conf  = ( $plugin_class => { select => '*', %{ $p{conf} || {} } } );
+    my $ct           = Code::TidyAll->new(
         quiet    => 1,
         root_dir => $self->{root_dir},
         plugins  => \%plugin_conf,
